@@ -14,7 +14,7 @@ from yams.buildobjs import (
     SubjectRelation, ObjectRelation, RichString, String, Date)
 
 from cubicweb.schema import (
-    RQLConstraint, RQLVocabularyConstraint, StaticVocabularyConstraint,
+    RQLConstraint, RQLVocabularyConstraint,
     ERQLExpression, RRQLExpression, WorkflowableEntityType)
 
 from cubes.tracker.schemaperms import (
@@ -110,10 +110,10 @@ class Ticket(WorkflowableEntityType):
                                            "configuration and some way to reproduce"
                                            " it whenever possible)"))
     priority = String(required=True, internationalizable=True,
-                      constraints=[StaticVocabularyConstraint((_('important'), _('normal'), _('minor')))],
+                      vocabulary=[_('important'), _('normal'), _('minor')],
                       description=_("importance"), default='normal')
     type = String(required=True, internationalizable=True,
-                  constraints=[StaticVocabularyConstraint((_('bug'), _('story')))],
+                  vocabulary=[_('bug'), _('enhancement'), _('task')],
                   description=_("type"), default='bug')
 
     ## relations
