@@ -2,7 +2,7 @@
 
 from datetime import date
 
-from cubicweb.devtools.testlib import WebTest, AutomaticWebTest
+from cubicweb.devtools.testlib import CubicWebTC, AutomaticWebTest
 
 
 class AutomaticWebTest(AutomaticWebTest):
@@ -19,14 +19,15 @@ class AutomaticWebTest(AutomaticWebTest):
             version.change_state('published')
 
 
-class VersionCalendarViews(WebTest):
+class VersionCalendarViews(CubicWebTC):
     """specific tests for calendar views"""
 
     def setup_database(self):
-        self.add_entity('Version', num=u'0.1.0', publication_date=date(2006, 2, 1))
-        self.add_entity('Version', num=u'0.2.0', publication_date=date(2006, 4, 1))
-        self.add_entity('Project', name=u"MyProject")
-        self.execute('SET V version_of P where V is Version, P is Project')
+        req = self.request()
+        req.create_entity('Version', num=u'0.1.0', publication_date=date(2006, 2, 1))
+        req.create_entity('Version', num=u'0.2.0', publication_date=date(2006, 4, 1))
+        req.create_entity('Project', name=u"MyProject")
+        req.execute('SET V version_of P where V is Version, P is Project')
 
     def test_calendars_for_versions(self):
         rset = self.execute('Version V')
