@@ -10,13 +10,13 @@ from logilab.common.textutils import normalize_text
 
 from cubicweb.view import EntityView
 from cubicweb.selectors import (implements, match_search_state, one_line_rset,
-                                two_lines_rset)
+                                multi_lines_rset)
 from cubicweb.entity import _marker
 from cubicweb.web import action
 
 class ReSTItemView(EntityView):
     __abstract__ = True
-    id = 'docitem'
+    __regid__ = 'docitem'
 
     title_underline = None # make pylint happy
     templatable = False
@@ -38,13 +38,13 @@ class ReSTItemView(EntityView):
             else:
                 value = entity.printable_value(attr, value, format='text/plain',
                                                **kwargs)
-            attr = self.req._(attr)
+            attr = self._cw._(attr)
         if value:
             self.w(u':%s: %s\n' % (attr, value))
 
     def cell_call(self, row, col):
         """ReST view for Project entities"""
-        entity = self.complete_entity(row, col)
+        entity = self.cw_rset.complete_entity(row, col)
         self._title(u'%s %s' % (entity.dc_type(), entity.dc_title()))
         self.render_attributes(entity)
         self.w(u'\n')
@@ -99,7 +99,7 @@ class VersionDocumentItemView(ReSTItemView):
             self.field(entity, 'prevision_date')
 
     def render_child(self, entity):
-        for ticket in self.req.execute(entity.tickets_rql()).entities():
+        for ticket in self._cw.execute(entity.tickets_rql()).entities():
             ticket.view('docitem', w=self.w)
 
 
@@ -114,11 +114,11 @@ class TicketDocumentItemView(ReSTItemView):
     def render_title(self, entity):
         self._title(u'%s #%s: %s [%s]' % (
             entity.dc_type(), entity.eid, entity.title,
-            self.req._(entity.priority)))
+            self._cw._(entity.priority)))
 
 
 class DocumentView(EntityView):
-    id = 'document'
+    __regid__ = 'document'
     __select__ = implements('Project', 'Version', 'Ticket')
 
     title = _('document')
@@ -127,22 +127,22 @@ class DocumentView(EntityView):
 
     def set_request_content_type(self):
         """overriden to set a .txt filename"""
-        self.req.set_content_type(self.content_type,
+        self._cw.set_content_type(self.content_type,
                                   filename='cubicwebexport.txt')
 
     def cell_call(self, row, col):
-        self.wview('docitem', self.rset, row=row, col=col)
+        self.wview('docitem', self.cw_rset, row=row, col=col)
 
     def call(self):
-        self.w(u'.. -*- coding: %s -*-\n\n' % self.req.encoding.lower())
-        for i in xrange(self.rset.rowcount):
+        self.w(u'.. -*- coding: %s -*-\n\n' % self._cw.encoding.lower())
+        for i in xrange(self.cw_rset.rowcount):
             self.cell_call(row=i, col=0)
 
 
 # actions ######################################################################
 
 class ProjectVersionExportAction(action.Action):
-    id = 'pvrestexport'
+    __regid__ = 'pvrestexport'
     __select__ = (match_search_state('normal') & one_line_rset() &
                   implements('Project', 'Version'))
 
@@ -150,16 +150,16 @@ class ProjectVersionExportAction(action.Action):
     order = 410
 
     def url(self):
-        entity = self.rset.get_entity(self.row or 0, self.col or 0)
+        entity = self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0)
         return entity.absolute_url(vid='document')
 
 
 class TicketRESTExportAction(action.Action):
-    id = 'ticketrestexport'
-    __select__ = (match_search_state('normal') & two_lines_rset() &
+    __regid__ = 'ticketrestexport'
+    __select__ = (match_search_state('normal') & multi_lines_rset() &
                   implements('Ticket'))
     title = _('ReST export')
 
     def url(self):
-        return self.build_url('view', rql=self.rset.printable_rql(),
-                              vid='document')
+        return self._cw.build_url('view', rql=self.cw_rset.printable_rql(),
+                                  vid='document')
