@@ -9,52 +9,52 @@ _ = unicode
 
 from logilab.mtconverter import xml_escape
 
+from cubicweb.view import EntityView
 from cubicweb.schema import display_name
-from cubicweb.selectors import objectify_selector, implements, two_lines_rset
-from cubicweb.common import tags, uilib
-from cubicweb.web import component, action
+from cubicweb.selectors import (objectify_selector, implements, multi_lines_rset,
+                                score_entity)
+from cubicweb import tags, uilib
+from cubicweb.web import uicfg, component, action
 from cubicweb.web.views import primary, baseviews
 
+_pvs = uicfg.primaryview_section
+
+_pvs.tag_attribute(('Ticket', 'title'), 'hidden')
+_pvs.tag_attribute(('Ticket', 'description'), 'attributes')
+
+_pvs.tag_subject_of(('Ticket', 'concerns', 'Project'), 'hidden')
+_pvs.tag_object_of(('Ticket', 'concerns', 'Project'), 'hidden')
+_pvs.tag_subject_of(('Ticket', 'done_in', 'Version'), 'attributes')
+_pvs.tag_object_of(('Ticket', 'done_in', 'Version'), 'attributes')
+
+_pvs.tag_subject_of(('Ticket', 'appeared_in', '*'), 'sideboxes')
+_pvs.tag_object_of(('Ticket', 'appeared_in', '*'), 'hidden')
+_pvs.tag_subject_of(('Ticket', 'depends_on', '*'), 'sideboxes')
+_pvs.tag_object_of(('*', 'depends_on', 'Ticket'), 'sideboxes')
+
+_pvdc = uicfg.primaryview_display_ctrl
+_pvdc.tag_attribute(('Ticket', 'description'), {'showlabel': False})
+
 # primary view and tabs ########################################################
 
 class TicketPrimaryView(primary.PrimaryView):
-    """common primary view for bug and story, relying on a mixin class
-    to be usable
+    """primary view for tickets
     """
-    __select__ = implements('Ticket')
+    __select__ = primary.PrimaryView.__select__ & implements('Ticket')
 
     def render_entity_title(self, entity):
-        self.w(u'<div class="titleGroup">')
-        title = xml_escape(entity.dc_title())
-        self.w(u'<h2><span class="%s %s">%s</span><span class="state"> [%s]</span></h2>\n'
-               % (entity.priority, entity.type, title,
-                  xml_escape(self.req._(entity.state))))
-        self.w(u'</div>')
-
-    ticket_attributes = ('type', 'priority', 'description' )
-
-    def render_entity_attributes(self, entity):
-        w = self.w
-        w(u'<table>')
-        for attr in self.ticket_attributes:
-            w(u'<tr class="row">')
-            w(u'<td class="label">%s</td><td>' % display_name(self.req, attr))
-            entity.view('reledit', rtype=attr, w=self.w)
-            w(u'</td></tr>\n')
-        w(u'</table>')
-        # Solved in
-        if entity.done_in:
-            w(u'<div class="label">%s %s</div>' % (self.req._('planned for'),
-                                                   entity.in_version().view('oneline')))
-        else:
-            w(self.req._('not planned'))
+        self.w(u'<h1><span class="%s %s">%s %s</span><span class="state"> [%s]</span></h1>'
+               % (entity.priority, entity.type,
+                  xml_escape(entity.project.name),
+                  xml_escape(entity.dc_title()),
+                  xml_escape(self._cw._(entity.state))))
 
 
 # pluggable sections ###########################################################
 
 class TicketIdenticalToVComponent(component.RelatedObjectsVComponent):
     """display identical tickets"""
-    id = 'tickectidentical'
+    __regid__ = 'tickectidentical'
     __select__ = component.RelatedObjectsVComponent.__select__ & implements('Ticket')
 
     rtype = 'identical_to'
@@ -68,7 +68,7 @@ class TicketIdenticalToVComponent(component.RelatedObjectsVComponent):
 # secondary views ##############################################################
 
 class TicketOneLineView(baseviews.OneLineView):
-    """one representation of a story / bug:
+    """one line representation of a ticket:
 
     call text view to get link's label, set entity's description on the
     link and display entity's status
@@ -76,28 +76,41 @@ class TicketOneLineView(baseviews.OneLineView):
     __select__ = implements('Ticket')
 
     def cell_call(self, row, col):
-        self.wview('incontext', self.rset, row=row)
-        entity = self.entity(row, col)
+        self.wview('incontext', self.cw_rset, row=row)
+        entity = self.cw_rset.get_entity(row, col)
         if entity.in_state:
-            self.w(u'&nbsp;[%s]' % xml_escape(self.req._(entity.state)))
+            self.w(u'&nbsp;[%s]' % xml_escape(self._cw._(entity.state)))
 
 
 class TicketInContextView(baseviews.OneLineView):
-    """one representation of a story / bug:
+    """in-context representation of a ticket:
 
     call text view to get link's label, set entity's description on the
     link and display entity's status
     """
-    id = 'incontext'
+    __regid__ = 'incontext'
     __select__ = implements('Ticket')
 
     def cell_call(self, row, col):
-        entity = self.entity(row, col)
+        self._cw.add_css('cubes.tracker.css')
+        entity = self.cw_rset.get_entity(row, col)
         self.w(tags.a(entity.dc_title(), href=entity.absolute_url(),
                       title=uilib.cut(entity.dc_description(), 80),
                       klass=entity.priority))
 
 
+class StatusSheetTicketView(EntityView):
+    __regid__ = 'instatussheet'
+    __select__ = implements('Ticket')
+
+    def cell_call(self, row, col):
+        entity = self.cw_rset.get_entity(row, col)
+        self.w(tags.div(tags.a('T%s' % entity.eid,
+                               href=xml_escape(entity.absolute_url())),
+                        title=xml_escape(entity.title),
+                        style='display: inline'))
+
+
 # actions ######################################################################
 
 @objectify_selector
@@ -156,37 +169,39 @@ class TicketAction(action.Action):
 
 
 class TicketMoveToNextVersionActions(TicketAction):
-    id = 'movetonext'
-    __select__ = TicketAction.__select__ & ticket_has_next_version()
+    __regid__ = 'movetonext'
+    __select__ = (TicketAction.__select__
+                  & score_entity(lambda x: x.state in x.OPEN_STATES)
+                  & ticket_has_next_version())
 
     submenu = _('move to version')
 
     def fill_menu(self, box, menu):
         # when there is only one item in the sub-menu, replace the sub-menu by
         # item's title prefixed by 'move to version'
-        menu.label_prefix = self.req._(self.submenu)
+        menu.label_prefix = self._cw._(self.submenu)
         super(TicketMoveToNextVersionActions, self).fill_menu(box, menu)
 
     def actual_actions(self):
-        for version in self.rset.maymovetoversions:
+        for version in self.cw_rset.maymovetoversions:
             yield self.build_action(version.num, self.url(version))
 
     def url(self, version):
-        if self.row is None:
-            eids = [str(row[self.col or 0]) for row in self.rset]
+        if self.cw_row is None:
+            eids = [str(row[self.cw_col or 0]) for row in self.cw_rset]
         else:
-            eids = [str(self.rset[self.row][self.col or 0])]
+            eids = [str(self.cw_rset[self.cw_row][self.cw_col or 0])]
         rql = 'SET X done_in V WHERE X eid IN(%s), V eid %%(v)s' % ','.join(eids)
-        msg = self.req._('tickets moved to version %s') % version.num
-        return self.user_rql_callback((rql, {'v': version.eid}, 'v'), msg)
+        msg = self._cw._('tickets moved to version %s') % version.num
+        return self._cw.user_rql_callback((rql, {'v': version.eid}, 'v'), msg)
 
 
 class TicketCSVExportAction(TicketAction):
-    id = 'ticketcsvexport'
-    __select__ = two_lines_rset() & TicketAction.__select__
+    __regid__ = 'ticketcsvexport'
+    __select__ = multi_lines_rset() & TicketAction.__select__
 
     title = _('csv export')
 
     def url(self):
-        return self.build_url('view', rql=self.rset.printable_rql(),
+        return self._cw.build_url('view', rql=self.cw_rset.printable_rql(),
                               vid='csvexport')
